@@ -13,23 +13,24 @@ LWP::Curl - LWP methods implementation with Curl engine
 
 =head1 VERSION
 
-Version 0.07
+Version 0.11
 
 =cut
 
-our $VERSION = '0.08.1';
+our $VERSION = '0.11.1';
 
 =head1 SYNOPSIS
 
-Use libcurl like LWP, $lwpcurl->get($url), $lwpcurl->timeout(15) don't care about Curl API and don't care about html encode
+  use LWP::Curl;
+   
+  my $lwpcurl = LWP::Curl->new();
+  my $content = $lwpcurl->get('http://search.cpan.org','http://www.cpan.org'); 
+  # get the page http://search.cpan.org passing with referer http://www.cpan.org
 
-    use LWP::Curl;
+=head1 DESCRIPTION
 
-    my $lwpcurl = LWP::Curl->new();
-	my $content = $lwpcurl->get('http://search.cpan.org','http://www.cpan.org'); 
-	#get the page http://search.cpan.org passing with referer http://www.cpan.org
-
-=cut
+LWP::Curl provides an interface similar to the LWP library, but is built on top of the Curl library.
+The simple LWP-style interface means you don't have to know anything about the underlying library.
 
 =head1 Constructor
 
@@ -77,10 +78,6 @@ Set the proxy in the constructor, $proxyurl will be like:
   all_proxy etc, if any of those are set. The $lwpcurl->proxy option does
   however override any possibly set environment variables. 
 
-=item * C<< cookie_jar => number >>
-
-Set how deep the spider will follow  when receive HTTP 301 ( Redirect ). The default is 3.
-
 =back
 
 =cut
@@ -144,60 +141,68 @@ sub new {
 
 =head2 $lwpcurl->get($url,$referer)
 
-  Get content of $url, passando $referer se definido
+Get content of $url, passing $referer if defined.
 
     use LWP::Curl;
 	my $referer = 'http://www.example.com';
 	my $get_url = 'http://www.example.com/foo';
     my $lwpcurl = LWP::Curl->new();
 	my $content = $lwpcurl->get($get_url, $referer); 
+
+The C<get> method croak()'s if the request fails, so wrap an C<eval> around it if you want to
+handle failure more elegantly.
+
 =cut
 
 sub get {
     my ( $self, $url, $referer ) = @_;
+    my $agent = $self->{agent};
 
     if ( !$referer ) {
         $referer = "";
     }
 	
 	$url = uri_escape($url,"[^:./]") if $self->{auto_encode};
-    $self->{agent}->setopt( CURLOPT_REFERER, $referer );
-    $self->{agent}->setopt( CURLOPT_URL,     $url );
-    $self->{agent}->setopt( CURLOPT_HTTPGET, 1 );
+    $agent->setopt( CURLOPT_REFERER, $referer );
+    $agent->setopt( CURLOPT_URL,     $url );
+    $agent->setopt( CURLOPT_HTTPGET, 1 );
 
     my $content = "";
     open( my $fileb, ">", \$content );
-    $self->{agent}->setopt( CURLOPT_WRITEDATA, $fileb );
-    $self->{retcode} = $self->{agent}->perform;
+    $agent->setopt( CURLOPT_WRITEDATA, $fileb );
+    $self->{retcode} = $agent->perform;
 
     if ( $self->{retcode} == 0 ) {
-        print("\nTransfer went ok\n") if $self->{debug};
-        return $content;
-    } else {
-        croak(  "An error happened: Host $url "
+        my $response_code = $agent->getinfo(CURLINFO_HTTP_CODE);
+        if ($response_code == 200 || ($response_code == 0 && $url =~ m!^file:!)) {
+            print("\nTransfer went ok\n") if $self->{debug};
+            return $content;
+        }
+    }
+
+    croak( "An error happened: Host $url "
               . $self->{agent}->strerror( $self->{retcode} )
               . " ($self->{retcode})\n" );
-		return undef;
-    }
+    return undef;
 }
 
 =head2 $lwpcurl->post($url,$hash_form,$referer) 
  
-  POST the $hash_form fields in $url, passing $referer if defined
+POST the $hash_form fields in $url, passing $referer if defined:
 
-    use LWP::Curl;
-
-    my $lwpcurl = LWP::Curl->new();
-
-	my $referer = 'http://www.examplesite.com/';
-	my $post_url = 'http://www.examplesite.com/post/';
-
-	my $hash_form = { 
-		'field1' => 'value1',
-		'field2' => 'value2',
-	}
-
-	my $content = $lwpcurl->post($post_url, $hash_form, $referer); 
+  use LWP::Curl;
+  
+  my $lwpcurl = LWP::Curl->new();
+  
+  my $referer = 'http://www.examplesite.com/';
+  my $post_url = 'http://www.examplesite.com/post/';
+  
+  my $hash_form = { 
+    'field1' => 'value1',
+    'field2' => 'value2',
+  }
+  
+  my $content = $lwpcurl->post($post_url, $hash_form, $referer); 
 
 =cut
 
@@ -239,14 +244,14 @@ sub post {
     $self->{retcode} = $self->{agent}->perform;
 
     if ( $self->{retcode} == 0 ) {
+        my $code;
 
-        #print("Transfer went ok\n");
-        #print STDERR $content;
-        return $content;
-
-        #my $response_code = $selfcurl->getinfo(CURLINFO_HTTP_CODE);
-    }
-    else {
+        $code = $self->{agent}->getinfo(CURLINFO_HTTP_CODE);
+        if ($code =~ /^2/) {
+            return $content;
+        }
+        croak "$code request not successful\n";
+    } else {
         croak(  "An error happened: Host $url "
               . $self->{agent}->strerror( $self->{retcode} )
               . " ($self->{retcode})\n" );
@@ -255,7 +260,8 @@ sub post {
 
 =head2 $lwpcurl->timeout($sec)
 
-  Set timeout, default 180
+Set the timeout to use for all subsequent requests, in seconds.
+Defaults to 180 seconds.
 
 =cut
 
@@ -270,7 +276,7 @@ sub timeout {
 
 =head2 $lwpcurl->auto_encode($value)
 
-  Turn on/off auto_encode
+Turn on/off auto_encode.
 
 =cut
 
@@ -284,10 +290,9 @@ sub auto_encode {
 
 =head2 $lwpcurl->agent_alias($alias)
    
-   Copy from L<WWW::Mechanize> begin here
-   ____________________________________
-   Sets the user agent string to the expanded version from a table of actual user strings.
-   I<$alias> can be one of the following:
+Sets the user agent string to the expanded version from a table
+of actual user strings.
+I<$alias> can be one of the following:
 
 =over 4
 
@@ -305,16 +310,13 @@ sub auto_encode {
 
 =back
 
-   then it will be replaced with a more interesting one.  For instance,
-   ____________________________________
+then it will be replaced with a more interesting one.  For instance,
 
-   Copy from L<WWW::Mechanize> ends here, but the idea and the data structure is a copy too :) 
-   
-   $lwpcurl->agent_alias( 'Windows IE 6' );
+  $lwpcurl->agent_alias( 'Windows IE 6' );
 
-	   sets your User-Agent to
-	    
-		Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)
+sets your User-Agent to
+
+  Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)
 
 =cut
 
@@ -362,37 +364,13 @@ $lwpcurl->proxy without argument, return the current proxy
 
 sub proxy {
     my ( $self, $proxy ) = @_;
-    if ( !$proxy ) {
+    if ( !defined $proxy ) {
         return $self->{proxy};
     }
 	$self->{proxy} = $proxy;
     $self->{agent}->setopt( CURLOPT_PROXY, $self->proxy );
 }
 
-=head2 $lwpcurl->cookie_jar($proxyurl)
-
-Set the proxy in the constructor, $proxyurl will be like:  
-    http://myproxy.com:3128/
-    http://username:password@proxy.com:3128/
-
-libcurl respects the environment variables http_proxy, ftp_proxy,
-all_proxy etc, if any of those are set. The $lwpcurl->proxy option does
-however override any possibly set environment variables. 
-
-To disable proxy set $lwpcurl->proxy('');
-
-$lwpcurl->proxy without argument, return the current proxy
-
-=cut
-
-sub cookie_jar {
-    my ( $self, $proxy ) = @_;
-    if ( !$proxy ) {
-        return $self->{proxy};
-    }
-	$self->{proxy} = $proxy;
-    $self->{agent}->setopt( CURLOPT_PROXY, $self->proxy );
-}
 =head1 TODO
 
 This is a small list of features I'm plan to add. Feel free to contribute with your wishlist and comentaries!
@@ -427,7 +405,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc LWP::Curl
 
-
 You can also look for information at:
 
 =over 4
@@ -455,7 +432,8 @@ L<http://search.cpan.org/dist/LWP-Curl>
 
 Thanks to Breno G. Oliveira for the great tips.    
 Thanks for the LWP and WWW::Mechanize for the inspiration.
-
+Thanks for Neil Bowers for patches
+ 
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Lindolfo Rodrigues de Oliveira Neto, all rights reserved.
